summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeimport/import_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codeimport/import_utils.h')
-rw-r--r--umbrello/umbrello/codeimport/import_utils.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/codeimport/import_utils.h b/umbrello/umbrello/codeimport/import_utils.h
index 965361f6..bec9e0ff 100644
--- a/umbrello/umbrello/codeimport/import_utils.h
+++ b/umbrello/umbrello/codeimport/import_utils.h
@@ -35,7 +35,7 @@ namespace Import_Utils {
*/
UMLObject* createUMLObject(Uml::Object_Type type,
const TQString& name,
- UMLPackage *tqparentPkg = NULL,
+ UMLPackage *parentPkg = NULL,
const TQString& comment = TQString(),
const TQString& stereotype = TQString());
/**
@@ -43,7 +43,7 @@ namespace Import_Utils {
* is put at the global scope.
*
* @param yesno When set to false, the object is created at the scope
* given by the tqparentPkg argument of createUMLObject().
*/
void putAtGlobalScope(bool yesno);
@@ -116,7 +116,7 @@ namespace Import_Utils {
/**
* Add an argument to a UMLOperation.
* The tqparentPkg arg is only used for resolving possible scope
* prefixes in the `type'.
*/
UMLAttribute* addMethodParameter(UMLOperation *method,
@@ -139,7 +139,7 @@ namespace Import_Utils {
* Create a generalization from the existing child UMLObject to the given
* tqparent class name.
*/
- void createGeneralization(UMLClassifier *child, const TQString &tqparentName);
+ void createGeneralization(UMLClassifier *child, const TQString &parentName);
/**
* Strip comment lines of leading whitespace and stars.
@@ -168,7 +168,7 @@ namespace Import_Utils {
/**
* Returns true if a type is an actual Datatype
*/
- bool isDatatype(const TQString& name, UMLPackage *tqparentPkg = NULL);
+ bool isDatatype(const TQString& name, UMLPackage *parentPkg = NULL);
} // end namespace Import_Utils
@@ -43,7 +43,7 @@ namespace Import_Utils {
*
* @param yesno When set to false, the object is created at the scope
- * given by the tqparentPkg argument of createUMLObject().
+ * given by the parentPkg argument of createUMLObject().
*/
void putAtGlobalScope(bool yesno);
@@ -116,7 +116,7 @@ namespace Import_Utils {
/**
* Add an argument to a UMLOperation.
- * The tqparentPkg arg is only used for resolving possible scope
+ * The parentPkg arg is only used for resolving possible scope
* prefixes in the `type'.
*/